# Decentralized Data Parallel (Decent-DP)

<p align="center">
  <img src="./docs/public/icon-light.png" />
</p>

<p align="center">
    <a href="https://wangzesen.github.io/Decent-DP/">Documentation</a>
</p>


## Introduction

The package is an PyTorch extension that faciliates efficient multi-worker decentralized data parallel training which fits in certain algorithm schemas.



<sup><a href="https://www.flaticon.com/free-icons/decentralization" title="decentralization icons">Icon created by zero_wing - Flaticon</a></sup>

